AstropyQuantity
===============

.. currentmodule:: pywwt.traits

.. autoclass:: AstropyQuantity
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~AstropyQuantity.default_value
      ~AstropyQuantity.info_text

   .. rubric:: Methods Summary

   .. autosummary::

      ~AstropyQuantity.validate

   .. rubric:: Attributes Documentation

   .. autoattribute:: default_value
   .. autoattribute:: info_text

   .. rubric:: Methods Documentation

   .. automethod:: validate
